.. meta::
    :description lang=en:
        Create text ads on a large scale with a simple Python function that
        works for any online advertising platform and/or ad template.

.. automodule:: advertools.ad_create
   :members:
   :undoc-members:
   :show-inheritance:
